@@ -10,8 +10,8 @@ NULL
 #'
 #' @details
 #' If \code{summary=TRUE} or \code{summary=NULL} and \code{name=NULL} a data.frame describing the 
-#' Datasheets is returned. If \code{optional=TRUE}, columns include: \code{scope}, \code{package}, 
-#' \code{name}, \code{displayName}, \code{isSingle}, \code{isOutput}, \code{data}. data only displayed for 
+#' Datasheets is returned. If \code{optional=TRUE}, columns include: \code{scope}, \code{packages}, 
+#' \code{name}, \code{displayName}, \code{isSingle}, \code{data}. data only displayed for 
 #' a SyncroSim \code{\link{Scenario}}. \code{dataInherited} and \code{dataSource} columns 
 #' added if a Scenario has dependencies. If \code{optional=FALSE}, columns include: 
 #' \code{scope}, \code{name}, \code{displayName}. All other arguments are ignored.
@@ -27,15 +27,15 @@ NULL
 #'          and the optional argument is ignored. Fast (1 less console command).
 #'   \item If SsimObject is a list of \code{\link{Scenario}} or \code{\link{Project}} 
 #'          objects (output from \code{\link{run}}, \code{\link{Scenario}} or 
-#'          \code{\link{Project}}): Adds ScenarioID/ProjectID column if appropriate.
-#'   \item If Scenario/Project is a vector: Adds ScenarioID/ProjectID column 
+#'          \code{\link{Project}}): Adds ScenarioId/ProjectId column if appropriate.
+#'   \item If Scenario/Project is a vector: Adds ScenarioId/ProjectId column 
 #'          as necessary.
 #'   \item If requested Datasheet has Scenario scope and contains info from more 
-#'          than one Scenario: ScenarioID/ScenarioName/ScenarioParent columns 
+#'          than one Scenario: ScenarioId/ScenarioName/ScenarioParent columns 
 #'          identify the Scenario by \code{name}, \code{id}, and \code{parent} (if a result Scenario).
 #'   \item If requested Datasheet has Project scope and contains info from more 
-#'          than one Project: ProjectID/ProjectName columns identify the Project 
-#'          by \code{name} and \code{id}.
+#'          than one Project: ProjectId/ProjectName columns identify the Project 
+#'          by \code{name} and \code{id}
 #' }
 #'
 #' @param ssimObject \code{\link{SsimLibrary}}, \code{\link{Project}},
@@ -62,7 +62,7 @@ NULL
 #' @param empty logical. If \code{TRUE} returns empty data.frames for each 
 #'     Datasheet. Ignored if \code{summary=TRUE} Default is \code{FALSE}
 #' @param filterColumn character string. The column to filter a Datasheet by. 
-#'     (e.g. "TransitionGroupID"). Note that to use the filterColumn argument,
+#'     (e.g. "TransitionGroupId"). Note that to use the filterColumn argument,
 #'     you must also specify the filterValue argument. Default is \code{NULL}
 #' @param filterValue character string or integer. The value to filter the 
 #'     filterColumn by. To use the filterValue argument, you must also specify
@@ -81,13 +81,18 @@ NULL
 #' @param fastQuery logical.  If \code{TRUE}, the request is optimized for 
 #'     performance.  Ignored if combined with summary, empty, or 
 #'     \code{\link{sqlStatement}} flags. Default is \code{FALSE}
-#' @param returnScenarioInfo logical. If \code{TRUE}, returns the Scenario ID,
-#'     Scenario Name, Parent ID, and Parent Name columns with the 
+#' @param returnScenarioInfo logical. If \code{TRUE}, returns the Scenario Id,
+#'     Scenario Name, Parent Id, and Parent Name columns with the 
 #'     Scenario-scoped Datasheet. Does nothing if the Datasheet exists at the
 #'     Library or Project level. Default is \code{FALSE}
 #' @param returnInvisible logical. If \code{TRUE}, returns columns that are 
 #'     invisible in the User Interface (i.e., are only used and populated
 #'     internally by SyncroSim or the SyncroSim Package). Default is \code{FALSE}
+#' @param rawValues logical. If \code{TRUE}, returns the raw ID values rather
+#'     than automatically translating the values to strings. Default is 
+#'     \code{FALSE}.
+#' @param verbose logical. If set to \code{FALSE}, will not print notes about
+#'     datasheet validation. Default is \code{TRUE}.
 #' 
 #' @return 
 #' If \code{summary=TRUE} returns a data.frame of Datasheet names 
@@ -97,7 +102,7 @@ NULL
 #' @examples 
 #' \dontrun{
 #' # Install helloworldSpatial package from package server
-#' addPackage("helloworldSpatial")
+#' installPackage("helloworldSpatial")
 #' 
 #' # Set the file path and name of the new SsimLibrary
 #' myLibraryName <- file.path(tempdir(),"testlib_datasheet")
@@ -108,9 +113,7 @@ NULL
 #' # Create a new SsimLibrary with the example template from helloworldSpatial
 #' myLibrary <- ssimLibrary(name = myLibraryName,
 #'                          session = mySession, 
-#'                          package = "helloworldSpatial",
-#'                          template = "example-library",
-#'                          forceUpdate = TRUE)
+#'                          packages = "helloworldSpatial")
 #'                          
 #' # Set the Project and Scenario
 #' myProject <- project(myLibrary, project = "Definitions")
@@ -124,39 +127,47 @@ NULL
 #' myDatasheetList <- datasheet(myScenario, summary = FALSE)
 #' 
 #' # Get a specific Datasheet
-#' myDatasheet <- datasheet(myScenario, name = "RunControl")
+#' myDatasheet <- datasheet(myScenario, name = "helloworldSpatial_RunControl")
 #' 
 #' # Include primary key when retrieving a Datasheet
-#' myDatasheet <- datasheet(myScenario, name = "RunControl", includeKey = TRUE)
+#' myDatasheet <- datasheet(myScenario, name = "helloworldSpatial_RunControl", 
+#'                          includeKey = TRUE)
 #' 
 #' # Return all columns, including optional ones
-#' myDatasheet <- datasheet(myScenario, name = "RunControl", summary = TRUE, 
-#'                          optional = TRUE)
+#' myDatasheet <- datasheet(myScenario, name = "helloworldSpatial_RunControl", 
+#'                          summary = TRUE, optional = TRUE)
 #' 
 #' # Return Datasheet as an element
-#' myDatasheet <- datasheet(myScenario, name = "RunControl", forceElements = TRUE)
+#' myDatasheet <- datasheet(myScenario, name = "helloworldSpatial_RunControl", 
+#'                          forceElements = TRUE)
 #' myDatasheet$helloworldSpatial_RunControl
 #' 
 #' # Get a Datasheet without pre-specified values
-#' myDatasheetEmpty <- datasheet(myScenario, name = "RunControl", empty = TRUE)
+#' myDatasheetEmpty <- datasheet(myScenario, 
+#'                               name = "helloworldSpatial_RunControl", 
+#'                               empty = TRUE)
 #' 
 #' # If Datasheet is empty, do not return dependencies as factors
-#' myDatasheetEmpty <- datasheet(myScenario, name = "RunControl", empty = TRUE,
+#' myDatasheetEmpty <- datasheet(myScenario, 
+#'                               name = "helloworldSpatial_RunControl", 
+#'                               empty = TRUE,
 #'                               lookupsAsFactors = FALSE)
 #'                               
 #' # Optimize query
-#' myDatasheet <- datasheet(myScenario, name = "RunControl", fastQuery = TRUE)
+#' myDatasheet <- datasheet(myScenario, name = "helloworldSpatial_RunControl", 
+#'                          fastQuery = TRUE)
 #' 
 #' # Get specific SsimLibrary core Datasheet
 #' myDatasheet <- datasheet(myLibrary, name = "core_Backup")
 #' 
 #' # Use an SQL statement to query a Datasheet
 #' mySQL <- sqlStatement(
-#'   groupBy = c("ScenarioID"),
+#'   groupBy = c("ScenarioId"),
 #'   aggregate = c("MinimumTimestep"),
 #'   where = list(MinimumTimestep = c(1))
 #' )
-#' myAggregatedDatasheet <- datasheet(myScenario, name = "RunControl",
+#' myAggregatedDatasheet <- datasheet(myScenario, 
+#'                                    name = "helloworldSpatial_RunControl",
 #'                                    sqlStatement = mySQL)
 #' }
 #' 
@@ -169,7 +180,8 @@ setGeneric("datasheet", function(ssimObject, name = NULL, project = NULL, scenar
                                  sqlStatement = list(select = "SELECT *", groupBy = ""), 
                                  includeKey = FALSE, forceElements = FALSE, 
                                  fastQuery = FALSE, returnScenarioInfo = FALSE,
-                                 returnInvisible = FALSE) standardGeneric("datasheet"))
+                                 returnInvisible = FALSE, rawValues = FALSE,
+                                 verbose = TRUE) standardGeneric("datasheet"))
 
 # Handles case where ssimObject is list of Scenario or Project objects
 #' @rdname datasheet
@@ -178,20 +190,25 @@ setMethod("datasheet",
           function(ssimObject, name, project, scenario, summary, optional, empty, 
                    filterColumn, filterValue, lookupsAsFactors, sqlStatement, 
                    includeKey, forceElements, fastQuery, returnScenarioInfo,
-                   returnInvisible) {
+                   returnInvisible, rawValues, verbose) {
+
   cScn <- ssimObject[[1]]
   x <- NULL
+  
   if (is(cScn, "Scenario")) {
     x <- getIdsFromListOfObjects(ssimObject, expecting = "Scenario", scenario = scenario, project = project)
     scenario <- x$objs
     project <- NULL
   }
+  
   if (is(cScn, "Project")) {
     x <- getIdsFromListOfObjects(ssimObject, expecting = "Project", scenario = scenario, project = project)
     project <- x$objs
     scenario <- NULL
   }
+  
   ssimObject <- x$ssimObject
+  
   if (is.null(ssimObject)) {
     stop("Expecting ssimObject to be an SsimLibrary/Project/Scenario, or a list of Scenarios/Projects.")
   }
@@ -203,7 +220,8 @@ setMethod("datasheet",
                     lookupsAsFactors = lookupsAsFactors, sqlStatement = sqlStatement, 
                     includeKey = includeKey, forceElements = forceElements, 
                     fastQuery = fastQuery, returnScenarioInfo = returnScenarioInfo,
-                    returnInvisible = returnInvisible)
+                    returnInvisible = returnInvisible, rawValues = rawValues,
+                    verbose = verbose)
   
   return(out)
 })
@@ -213,7 +231,8 @@ setMethod("datasheet",
           signature(ssimObject = "character"), 
           function(ssimObject, name, project, scenario, summary, optional, empty, 
                    filterColumn, filterValue, lookupsAsFactors, sqlStatement, 
-                   includeKey, fastQuery, returnScenarioInfo, returnInvisible) {
+                   includeKey, fastQuery, returnScenarioInfo, returnInvisible,
+                   rawValues, verbose) {
   return(SyncroSimNotFound(ssimObject))
 })
 
@@ -223,43 +242,50 @@ setMethod("datasheet",
           function(ssimObject, name, project, scenario, summary, optional, empty, 
                    filterColumn, filterValue, lookupsAsFactors, sqlStatement, 
                    includeKey, forceElements, fastQuery, returnScenarioInfo,
-                   returnInvisible) {
+                   returnInvisible, rawValues, verbose) {
+            
   temp <- NULL
-  ProjectID <- NULL
-  ScenarioID <- NULL
+  ProjectId <- NULL
+  ScenarioId <- NULL
   colOne <- NULL
-  ParentID <- NULL
+  ParentId <- NULL
   ParentName <- NULL
   Name <- NULL
-  xProjScn <- .getFromXProjScn(ssimObject, project, scenario, returnIds = TRUE, convertObject = FALSE, complainIfMissing = TRUE)
-  IDColumns <- c("ScenarioID", "ProjectID")
+  xProjScn <- .getFromXProjScn(ssimObject, project, scenario, returnIds = TRUE, 
+                               convertObject = FALSE, complainIfMissing = TRUE)
+  IDColumns <- c("ScenarioId", "ProjectId")
+  
+  if (is(ssimObject, "SsimLibrary")){
+    scopeDS <- "library"
+  } else if (is(ssimObject, "Project")){
+    scopeDS <- "project"
+  } else {
+    scopeDS <- "scenario"
+  }
   
   if (is(xProjScn, "SsimLibrary")) {
     x <- xProjScn
     pid <- NULL
     sid <- NULL
+    scopeDS <- "library"
   } else {
     x <- xProjScn$ssimObject
     pid <- xProjScn$project
     sid <- xProjScn$scenario
+    
     if (!is.null(sid) & is.null(pid)) {
-      pid <- subset(xProjScn$scenarioSet, is.element(ScenarioID, sid))$ProjectID
+      pid <- subset(xProjScn$scenarioSet, is.element(ScenarioId, sid))$ProjectId
     }
   }
+  
   # now have valid pid/sid vectors and x is library.
   if (!is.null(name)) {
     for (i in seq_along(name)) {
       n <- name[i]
       if (!grepl("_", n, fixed = TRUE)) {
-        l = ssimLibrary(.filepath(ssimObject), summary=T)
-        p = l$value[l$property == "Package Name:"]
-        n <- paste0(p, "_", n)
-      }
-      
-      if (grepl("STSim_", n, fixed = TRUE)) {
-        warning("An STSim_ prefix for a datasheet name is no longer required.")
-        n <- paste0("stsim_", gsub("STSim_", "", n, fixed = TRUE))
+        stop("The datasheet name requires a package prefix (e.g., 'stsim_RunControl')")
       }
+    
       name[i] <- n
     }
   }
@@ -274,29 +300,32 @@ setMethod("datasheet",
     }
   }
   
-  if (summary == "CORE"){
-    summary <- TRUE
-  }
-  
   # if summary, don't need to bother with project/scenario ids: sheet info doesn't vary among project/scenarios in a project
   if (summary == TRUE) {
     sumInfo <- .datasheets(x, project[[1]], scenario[[1]], core = TRUE)
+    
     if (nrow(sumInfo) == 0) {
       stop("No datasheets available")
     }
+    
     sumInfo$order <- seq(1, nrow(sumInfo))
+    
     if (is.null(name)) {
       name <- sumInfo$name
       allNames <- name
     }
+    
     missingSheets <- setdiff(name, sumInfo$name)
+    
     if (length(missingSheets) > 0) {
       sumInfo <- .datasheets(x, project[[1]], scenario[[1]], refresh = TRUE)
       missingSheets <- setdiff(name, sumInfo$name)
+      
       if (length(missingSheets) > 0) {
         stop(paste0("Datasheets not found: ", paste(missingSheets, collapse = ",")))
       }
     }
+    
     sumInfo <- subset(sumInfo, is.element(name, allNames))
   }
   
@@ -309,22 +338,30 @@ setMethod("datasheet",
   }
   
   if ((summary == TRUE) & !optional) {
+    
     sumInfo <- subset(sumInfo, select = c("scope", "name", "displayName", "order"))
     sumInfo[order(sumInfo$order), ]
     sumInfo$order <- NULL
+    sumInfo <- sumInfo[sumInfo$scope == scopeDS,]
+    
     return(sumInfo)
   }
   
   # Add data info - only for scenario scope datasheets if sid is defined
   if (summary == TRUE) {
+    
     # if no scenario scope sheets, return sumInfo without checking for data
     scnSheetSum <- sum(sumInfo$scope == "scenario")
     
     if (scnSheetSum == 0) {
+      
       sumInfo[order(sumInfo$order), ]
       sumInfo$order <- NULL
+      sumInfo <- sumInfo[sumInfo$scope == scopeDS,]
+      
       return(sumInfo)
     }
+    
     for (i in seq(length.out = length(sid))) {
       cSid <- sid[i]
       tt <- command(list(list = NULL, datasources = NULL, lib = .filepath(x), sid = cSid), session = session(x))
@@ -362,6 +399,8 @@ setMethod("datasheet",
     sumInfo <- subset(sumInfo, select = c(prevNames, setdiff(names(sumInfo), prevNames)))
     sumInfo <- sumInfo[order(sumInfo$order, sumInfo$scenario), ]
     sumInfo$order <- NULL
+    sumInfo <- sumInfo[sumInfo$scope == scopeDS,]
+    
     return(sumInfo)
   }
   
@@ -372,6 +411,7 @@ setMethod("datasheet",
   for (kk in seq(length.out = length(allNames))) {
     
     if (summary == FALSE) {
+      
       name <- allNames[kk] # TODO see if name and cName are fullt subsituable
       cName <- name
       datasheetNames <- .datasheets(x, scope = "all")
@@ -401,6 +441,7 @@ setMethod("datasheet",
         if (!(filterColumn %in% datasheetCols$name)) {
           filterColumn <- NULL
         }
+        #TODO: remove isOutput here and test
         else if (is.na(suppressWarnings(as.integer(filterValue)))) {
           if (sheetNames$isOutput){
             inputDatasheetName <- subset(datasheetCols, name == filterColumn)$formula1
@@ -434,32 +475,25 @@ setMethod("datasheet",
     }
     
     rmCols <- c()
-
-    if (!sheetNames$isOutput) {
-      if (!includeKey) {
-        args <- list(list = NULL, columns = NULL, allprops = NULL, csv = NULL, lib = .filepath(x), sheet = name)
-        tt <- command(args, session = session(x))
-        cPropsAll <- .dataframeFromSSim(tt)
-        filtered <- cPropsAll[grep("isPrimary^Yes", cPropsAll$properties, fixed = TRUE), ]
-        if (nrow(filtered) > 0) {
-          rmCols <- filtered[1]
-        }
+    
+    if (!includeKey) {
+      args <- list(list = NULL, columns = NULL, allprops = NULL, csv = NULL, lib = .filepath(x), sheet = name)
+      tt <- command(args, session = session(x))
+      cPropsAll <- .dataframeFromSSim(tt)
+      filtered <- cPropsAll[grep("isPrimary^Yes", cPropsAll$properties, fixed = TRUE), ]
+      if (nrow(filtered) > 0) {
+        rmCols <- filtered[1]
       }
     }
     
-    # Use console means using the console either to write out a querry to file OR
+    # Use console means using the console either to write out a query to file OR
     # write the datasheet directly
-    useConsole <- FALSE
+    useConsole <- TRUE
     tempFile <- paste0(.tempfilepath(x), "/", name, ".csv")
     
     if (!empty) {
       # If non empty set, carry on with the retrieving of data
       
-      # Only query database if output or multiple scenarios/project or complex sql
-      # UseConsole TRUE only if is NOT AN output, 
-      # Basically an output will make keep console FALSE
-      useConsole <- (!sheetNames$isOutput)
-      
       # Use console if filterColumn argument is used
       if (!is.null(filterColumn)){
         useConsole <- TRUE
@@ -517,11 +551,11 @@ setMethod("datasheet",
               # Adding pid and sid because the sql query generated by the 
               # console does not include them
               if (nrow(sheet) > 0 & (length(pid)>1 | length(sid)>1)){
-                sheet$ScenarioID <- sid[id]
-                sheet$ProjectID <- pid[id]
+                sheet$ScenarioId <- sid[id]
+                sheet$ProjectId <- pid[id]
               } else if (length(sid) == 1 && returnScenarioInfo){
-                sheet$ScenarioID <- sid
-                sheet$ProjectID <- pid
+                sheet$ScenarioId <- sid
+                sheet$ProjectId <- pid
               }
               
               # Rearrange on the spot, making sure this is robust for Project-level
@@ -556,6 +590,11 @@ setMethod("datasheet",
             args[["filtercol"]] <- filterColumn
           }
           
+          if (rawValues){
+            args[["valSheet"]] <- NULL
+            args <- append(args, list(rawvalues = NULL))
+          }
+          
           tt <- command(args, .session(x))
           
           if (!identical(tt, "saved")) {
@@ -588,9 +627,9 @@ setMethod("datasheet",
             # following https://faculty.washington.edu/kenrice/sisg-adv/sisg-09.pdf
             # and https://www.sqlitetutorial.net/sqlite-in/
             if (sqlStatement$where == "") {
-              sqlStatement$where <- paste0("WHERE ScenarioID IN (", paste(sid, collapse = ","), ")")
+              sqlStatement$where <- paste0("WHERE ScenarioId IN (", paste(sid, collapse = ","), ")")
             } else {
-              sqlStatement$where <- paste0(sqlStatement$where, " AND (ScenarioID IN (", paste(sid, collapse = ","), "))")
+              sqlStatement$where <- paste0(sqlStatement$where, " AND (ScenarioId IN (", paste(sid, collapse = ","), "))")
             }
           }
         }
@@ -600,9 +639,9 @@ setMethod("datasheet",
             stop("Specify a project.")
           } else {
             if (sqlStatement$where == "") {
-              sqlStatement$where <- paste0("WHERE ProjectID IN (", paste(pid, collapse = ","), ")")
+              sqlStatement$where <- paste0("WHERE ProjectId IN (", paste(pid, collapse = ","), ")")
             } else {
-              sqlStatement$where <- paste0(sqlStatement$where, " AND (ProjectID IN (", paste(pid, collapse = ","), "))")
+              sqlStatement$where <- paste0(sqlStatement$where, " AND (ProjectId IN (", paste(pid, collapse = ","), "))")
             }
           }
         }
@@ -677,7 +716,9 @@ setMethod("datasheet",
         cRow <- sheetInfo[i, ]
         
         if (!is.element(cRow$name, colnames(sheet))) {
-          if (sqlStatement$select == "SELECT *") {
+          if (cRow$name == "ScenarioId"){
+            sheet[[cRow$name]] <- sid
+          } else if (sqlStatement$select == "SELECT *") {
             sheet[[cRow$name]] <- NA
           } else {
             next
@@ -739,18 +780,18 @@ setMethod("datasheet",
                 lookupSheet <- read.csv(lookupPath, as.is = TRUE)
               }
             }
-            if (is.element("ProjectID", names(lookupSheet))) {
+            if (is.element("ProjectId", names(lookupSheet))) {
               if (identical(pid, NULL) & !identical(sid, NULL)) {
                 allScns <- scenario(x)
-                findPrjs <- allScns$ProjectID[is.element(allScns$ScenarioID, sid)]
+                findPrjs <- allScns$ProjectId[is.element(allScns$ScenarioId, sid)]
               } else {
                 findPrjs <- pid
               }
-              lookupSheet <- subset(lookupSheet, is.element(ProjectID, pid))
+              lookupSheet <- subset(lookupSheet, is.element(ProjectId, pid))
             }
-            if (is.element("ScenarioID", names(lookupSheet))) {
+            if (is.element("ScenarioId", names(lookupSheet))) {
               if (!is.null(sid)) {
-                lookupSheet <- subset(lookupSheet, is.element(ScenarioID, sid))
+                lookupSheet <- subset(lookupSheet, is.element(ScenarioId, sid))
               }
             }
             if ((nrow(lookupSheet) == 0) & (cRow$optional == "No")) {
@@ -785,16 +826,14 @@ setMethod("datasheet",
             sheet[[cRow$name]] <- as.character(sheet[[cRow$name]])
           }
         }
-        if (cRow$valType != "List") {
-          if (cRow$formula2 != "N/A") {
-            if (cRow$valCond == "Between") {
-              print(paste0("Note: ", cRow$name, " should be between ", cRow$formula1, " and ", cRow$formula2))
-            } else {
-              stop("handle this case")
-            }
+        
+        if (cRow$valType != "List" && cRow$formula2 != "N/A") {
+          if (cRow$valCond == "Between" && verbose) {
+            print(paste0("Note: ", cRow$name, " should be between ", cRow$formula1, " and ", cRow$formula2))
           }
         }
       }
+      
       if (lookupsAsFactors && !useConsole && directQuery) {
         DBI::dbDisconnect(con)
       }
@@ -821,23 +860,23 @@ setMethod("datasheet",
       }
     }
     
-    if (is.element("ProjectID", names(sheet))) {
+    if (is.element("ProjectId", names(sheet))) {
       if (length(pid) == 1) {
-        sheet$ProjectID <- NULL
+        sheet$ProjectId <- NULL
       } else {
         if (nrow(sheet) > 0) {
           allProjects <- .project(x)
-          names(allProjects) <- c("ProjectID", "ProjectName")
+          names(allProjects) <- c("ProjectId", "ProjectName")
           sheet <- merge(allProjects, sheet, all.y = TRUE)
         }
       }
     }
-    if (is.element("ScenarioID", names(sheet))) {
+    if (is.element("ScenarioId", names(sheet))) {
       if (length(sid) > 1){
         returnScenarioInfo <- TRUE
       }
       if (length(sid) == 1){
-        sheet$ScenarioID <- NULL
+        sheet$ScenarioId <- NULL
       }
       if (nrow(sheet) > 0 && returnScenarioInfo) {
         if (is(x, "SsimLibrary")){
@@ -846,25 +885,27 @@ setMethod("datasheet",
           lib <- .ssimLibrary(x)
         }
         allScns <- scenario(lib, summary = TRUE)
-        if (!is.element("ParentID", names(allScns))) {
-          warning("Missing ParentID info from scenario(summary=TRUE).")
-          allScns$ParentID <- NA
+        if (!is.element("ParentId", names(allScns))) {
+          warning("Missing ParentId info from scenario(summary=TRUE).")
+          allScns$ParentId <- NA
         }
-        allScns <- subset(allScns, select = c(ScenarioID, ProjectID, Name, ParentID))
-        allScns$ParentID <- suppressWarnings(as.numeric(allScns$ParentID))
-        parentNames <- subset(allScns, select = c(ScenarioID, Name))
-        names(parentNames) <- c("ParentID", "ParentName")
+        allScns <- subset(allScns, select = c(ScenarioId, ProjectId, Name, ParentId))
+        allScns$ParentId <- suppressWarnings(as.numeric(allScns$ParentId))
+        parentNames <- subset(allScns, select = c(ScenarioId, Name))
+        names(parentNames) <- c("ParentId", "ParentName")
         allScns <- merge(allScns, parentNames, all.x = T)
         
-        allScns <- subset(allScns, select = c(ScenarioID, ProjectID, Name, ParentID, ParentName))
+        allScns <- subset(allScns, select = c(ScenarioId, ProjectId, Name, ParentId, ParentName))
         
-        names(allScns) <- c("ScenarioID", "ProjectID", "ScenarioName", "ParentID", "ParentName")
-        allScns <- allScns[allScns$ScenarioID %in% sid,]
+        names(allScns) <- c("ScenarioId", "ProjectId", "ScenarioName", "ParentId", "ParentName")
+        allScns <- allScns[allScns$ScenarioId %in% sid,]
         
+        sheet <- sheet[, !(names(sheet) %in% "ScenarioId")]
         sheet <- merge(allScns, sheet, all.y = TRUE)
       }
     }
     
+    sheet <- sheet[rowSums(is.na(sheet)) != ncol(sheet), , drop = FALSE]
     outSheetList[[cName]] <- sheet
     
     # return single row datasheets as named vectors (if not for multiple scenarios)
