@@ -7,8 +7,7 @@ dir.create(temp_dir)
 setwd(temp_dir)
 
 mySsim <- session()
-addPackage(session = mySsim, name = "stsimsf")
-addPackage(session = mySsim, name = "helloworld")
+installPackage(session = mySsim, packages = c("stsim", "helloworld"))
 
 test_that("Tests of Session - assumes SyncroSim is installed", {
   skip_on_cran()
@@ -51,26 +50,9 @@ test_that("Tests of Library - assumes SyncroSim is installed", {
   expect_equal(file.exists(filepath(myLibrary)), TRUE)
   expect_equal(name(myLibrary), "SSimLibrary")
   
-  # With addons
-  expect_equal(nrow(subset(addon(myLibrary), enabled)), 0)
-  allAdds <- addon(myLibrary)
-  expect_equal(names(allAdds), c("name", "description", "enabled", "currentVersion", "minimumVersion"))
-  expect_equal(names(addon(mySsim)), c("name", "description", "version", "extends"))
+  # Test delete
   expect_equal(delete(myLibrary, force = TRUE), TRUE)
   
-  allAdds <- subset(allAdds, name != "stsim-cbm") # Requires stsim-stockflow to be added first
-  
-  if (nrow(allAdds) > 0) {
-    cAdd <- allAdds$name[1]
-    # TODO Fails to detect stsimsf is installed => potential bug with console
-    myLibrary <- ssimLibrary(name = "NewLibrary", addon = c(cAdd), session = mySsim)
-    expect_equal(subset(addon(myLibrary), enabled)$name, cAdd)
-    expect_equal(disableAddon(myLibrary, cAdd)[[cAdd]], TRUE)
-    expect_equal(nrow(subset(addon(myLibrary), enabled)), 0)
-    expect_equal(enableAddon(myLibrary, cAdd)[[cAdd]], TRUE)
-    expect_equal(subset(addon(myLibrary), enabled)$name, cAdd)
-  }
-  
   # Get/set the various properties of the library
   expect_is("session<-"(myLibrary, mySsim), "SsimLibrary")
   
@@ -106,15 +88,15 @@ test_that("Tests of projects and scenarios - assumes SyncroSim is installed", {
   myOtherScn <- scenario(myOtherLibProj, scenario = "other")
   
   expect_is(myOtherScn, "Scenario")
-  expect_equal(scenario(myOtherLib)$ScenarioID, 1)
+  expect_equal(scenario(myOtherLib)$ScenarioId, 1)
   ret <- delete(myOtherLib, scenario = "other", force = TRUE)
   expect_equal(nrow(scenario(myOtherLib)), 0)
   myOtherScn <- scenario(myOtherLib, scenario = "other2")
   
-  expect_equal(names(project(myOtherLib)), c("ProjectID", "Name", "Owner",
+  expect_equal(names(project(myOtherLib)), c("ProjectId", "Name", "Owner",
                                              "DateLastModified", "IsReadOnly"))
-  expect_equal(names(scenario(myOtherLib)), c("ScenarioID", "ProjectID", "Name",
-                                              "IsResult", "ParentID", "Owner",
+  expect_equal(names(scenario(myOtherLib)), c("ScenarioId", "ProjectId", "Name",
+                                              "IsResult", "ParentId", "Owner",
                                               "DateLastModified", "IsReadOnly",
                                               "MergeDependencies",
                                               "IgnoreDependencies",
@@ -168,7 +150,7 @@ test_that("Tests of projects and scenarios - assumes SyncroSim is installed", {
   allScns <- scenario(myProject, summary = FALSE)
   expect_equal(names(allScns), c("4", "5", "6"))
   
-  expect_equal(is.element("ScenarioID", names(datasheet(myLib, c("RunControl", "OutputOptions"), scenario = as.numeric(names(allScns)))[[1]])), TRUE) # returns a list - each sheet contains scenario info if appropriate
+  expect_equal(is.element("ScenarioId", names(datasheet(myLib, c("RunControl", "OutputOptions"), scenario = as.numeric(names(allScns)))[[1]])), TRUE) # returns a list - each sheet contains scenario info if appropriate
   
   expect_equal(length(datasheet(allScns, c("RunControl", "OutputOptions"))), 2) # returns a list - each sheet contains scenario info if appropriate
   
@@ -286,4 +268,4 @@ test_that("Tests of datasheet - assumes SyncroSim is installed", {
 })
 
 setwd(old_dir)
-unlink(temp_dir, recursive = TRUE)
\ No newline at end of file
+unlink(temp_dir, recursive = TRUE)
